/*****************************************************************************
 *   eeprom.c:  Driver for the LM75 temperature sensor
 *
 *   Copyright(C) 2011, Embedded Artists AB
 *   All rights reserved.
 *
 ******************************************************************************/

/*
 * NOTE: I2C must have been initialized before calling any functions in this
 * file.
 */

/******************************************************************************
 * Includes
 *****************************************************************************/

#include "type.h"
#include "i2c.h"

/******************************************************************************
 * Defines and typedefs
 *****************************************************************************/



#define LM75B_I2C_ADDR	(0x48)
#define LM75B_REG_TEMP	0x00
#define LM75B_REG_CMD	0x01


/******************************************************************************
 * External global variables
 *****************************************************************************/

/******************************************************************************
 * Local variables
 *****************************************************************************/


/******************************************************************************
 * Local Functions
 *****************************************************************************/
#define I2C_CODE_OK    1
#define I2C_CODE_ERR  50



static int8_t
lm75(uint8_t lmAddr, uint8_t* pBuf, uint16_t len, uint8_t* pBuf2, uint16_t len2)
{
  int8_t retCode = I2C_CODE_OK;


  // write only
  if (len2 == 0) {
	  I2CWrite((lmAddr << 1), pBuf, len);
  }
  else {
	  I2CWrite((lmAddr << 1), pBuf, len);
	  I2CRead((lmAddr << 1), pBuf2, len2);
  }

  return retCode;
}

/******************************************************************************
 * Public Functions
 *****************************************************************************/

/******************************************************************************
 *
 * Description:
 *    Initialize the EEPROM Driver
 *
 *****************************************************************************/
void lm75b_init (void)
{

}

/******************************************************************************
 *
 * Description:
 *    Read the temperature
 *
 * Params: None
 *
 * Returns:
 *   The measured temperature x 100, i.e. 26.50 degrees returned as 2650
 *
 *****************************************************************************/
int32_t lm75b_readTemp(void)
{
    uint8_t cmd = LM75B_REG_TEMP;
    uint8_t temp[2];
    int16_t t = 0;


    //                 lm75(i2c-addr,      *pBuf, len, *pBuf2, len2
    if (I2C_CODE_OK == lm75(LM75B_I2C_ADDR, &cmd,   1,   temp,   2))
    {
        /* 11 MSB bits used. Celcius is calculated as Temp data * 1/8 */
        t = ((temp[0] << 8) | (temp[1]));

        return ((t * 100) >> 8);
    }
    else
    	return 0xffff;
}

/******************************************************************************
 *
 * Description:
 *    Write to config register of LM75B
 *
 * Params: Config byte
 *
 * Returns: None
 *
 *****************************************************************************/
int8_t lm75b_config(int8_t config)
{
    uint8_t cmd[2];


    cmd[0] = LM75B_REG_CMD;
    cmd[1] = config;
    //                 lm75(i2c-addr,      *pBuf, len, *pBuf2, len2
    return lm75(LM75B_I2C_ADDR, &cmd[0],   2,   NULL,   0);
}


